@@ -520,6 +520,35 @@ TEST_DATA = {
                 "Notes": "6X SLF",
             },
         },
+        "UChicagoExample1": {
+            "path": join(
+                DIRECTORIES["SNCPATIENT2020_EXAMPLES"],
+                "UChicago",
+                "DCAM_example_1.pdf",
+            ),
+            "data": {
+                "Patient Name": "",
+                "Patient ID": "",
+                "QA Date": "",
+                "Plan Date": "",
+                "Plan Name": "",
+                "Plan ID": "",
+                "Verified Plan UID": "",
+                "Total MU": "3352.99",
+                "Comparison Type": "Absolute Dose Comparison (DTA/Gamma using 2D Mode)",
+                "Threshold (%)": "10",
+                "Use Global (%)": "Yes",
+                "Difference (%)": "3",
+                "Meas Uncertainty": "No",
+                "Distance (mm)": "2.0",
+                "Summary Type": "Summary (Gamma Analysis)",
+                "Pass (%)": "92.3",
+                "Pass": "717",
+                "Fail": "60",
+                "Total Points": "777",
+                "Notes": "2-1 Composite",
+            },
+        },
     },
     "verisoft": {
         "ABMC1": {
